@@ -99,18 +99,10 @@ setMethod(f = "make_layout",
     }
     if(length(column_title) > 0) {
         if(column_title_side == "top") {
-            if(column_title_rot %in% c(0, 180)) {
-                object@layout$layout_size$column_title_top_height = grobHeight(textGrob(column_title, gp = column_title_gp)) + sum(title_padding)
-            } else {
-                object@layout$layout_size$column_title_top_height = grobWidth(textGrob(column_title, gp = column_title_gp)) + sum(title_padding)
-            }
+            object@layout$layout_size$column_title_top_height = grobHeight(textGrob(column_title, gp = column_title_gp, rot = column_title_rot)) + sum(title_padding)
             object@layout$layout_index = rbind(object@layout$layout_index, column_title_top = heatmap_layout_index("column_title_top"))
         } else {
-            if(column_title_rot %in% c(0, 180)) {
-                object@layout$layout_size$column_title_bottom_height = grobHeight(textGrob(column_title, gp = column_title_gp)) + sum(title_padding)
-            } else {
-                object@layout$layout_size$column_title_bottom_height = grobWidth(textGrob(column_title, gp = column_title_gp)) + sum(title_padding)
-            }
+            object@layout$layout_size$column_title_bottom_height = grobHeight(textGrob(column_title, gp = column_title_gp, rot = column_title_rot)) + sum(title_padding)
             object@layout$layout_index = rbind(object@layout$layout_index, column_title_bottom = heatmap_layout_index("column_title_bottom"))
         }
         object@layout$graphic_fun_list = c(object@layout$graphic_fun_list, function(object) {
@@ -139,18 +131,10 @@ setMethod(f = "make_layout",
     }
     if(length(row_title) > 0) {
         if(row_title_side == "left") {
-            if(row_title_rot %in% c(0, 180)) {
-                object@layout$layout_size$row_title_left_width = max_text_width(row_title, gp = row_title_gp) + sum(title_padding)
-            } else {
-                object@layout$layout_size$row_title_left_width = max_text_height(row_title, gp = row_title_gp) + sum(title_padding)
-            }
+            object@layout$layout_size$row_title_left_width = max_text_width(row_title, gp = row_title_gp, rot = row_title_rot) + sum(title_padding)
             object@layout$layout_index = rbind(object@layout$layout_index, row_title_left = heatmap_layout_index("row_title_left"))
         } else {
-            if(row_title_rot %in% c(0, 180)) {
-                object@layout$layout_size$row_title_right_width = max_text_width(row_title, gp = row_title_gp) + sum(title_padding)
-            } else {
-                object@layout$layout_size$row_title_right_width = max_text_height(row_title, gp = row_title_gp) + sum(title_padding)
-            }
+            object@layout$layout_size$row_title_right_width = max_text_width(row_title, gp = row_title_gp, rot = row_title_rot) + sum(title_padding)
             object@layout$layout_index = rbind(object@layout$layout_index, row_title_right = heatmap_layout_index("row_title_right"))
         }
         object@layout$graphic_fun_list = c(object@layout$graphic_fun_list, function(object) {
@@ -268,7 +252,6 @@ setMethod(f = "make_layout",
                 draw_dend(object, k = i, which = "column", x = slice_x[i], width = slice_width[i], just = "left",
                     max_height = column_dend_max_height)
             }
-
             if(nc_slice > 1 && cluster_column_slices) {
                 if(column_dend_side == "top") {
                     pushViewport(viewport(yscale = c(0, column_dend_max_height)))
@@ -285,6 +268,7 @@ setMethod(f = "make_layout",
                 for(i in seq_len(nc_slice)) {
                     slice_leaf_pos[i] = slice_leaf_pos[i] + slice_width[i]*p[i]
                 }
+
                 if(!object@column_dend_param$split_by_cutree) {
                     column_dend_slice = merge_dendrogram(column_dend_slice, object@column_dend_list, only_parent = TRUE)
                 }
